#!/usr/bin/php
<?php
/**
 * fsl2006 congress
 * topic: PHP router in Asterisk
 * author: Moises Silva <moy@ivsol.net>
 * @package fsl-astcallmanager
 */
/**
 * simple router based on MAGI patch
 */
require_once 'AmiConnector.php';
require_once '../agi_router/RouteHoncho.php';
Logger::SetLogLevel(100);
try
{
	$honcho    = new RouteHoncho();
	$connector = new AmiConnector();
	$connector->SetAuthenticationInfo('vaio', 'managerpass');
	$connector->ConnectToManager();
	while ( TRUE )
	{
		$packets = $connector->ReceiveManagerPackets();	
		foreach ( $packets as $packet )
		{
			if ( isset($packet['Event']) && 'magiexec' == strtolower($packet['Event']) )
			{
				Logger::WriteLog("Starting New call Routing");
				
				$channel   = $packet['Channel'];

				$magi_data = AmiConnector::ParseMagiExecResult($packet['Result']);
				
				/* get the dialed number by the user */
				$dialed    = $magi_data['agi_extension'];
				
				/* get whos calling */
				$callerid  = $magi_data['agi_callerid'];

				/* get where wants to call */
				$mapping   = $honcho->GetNumberMapping($dialed);

				Logger::WriteLog('Dialed Number: ' . $dialed);
				if ( NULL === $mapping )
				{
					Logger::WriteLog('invalid number');
					$connector->Playback($channel, 'iss_invalid_pbx_number');
					$connector->Hangup($channel);
				}
				else
				{
					Logger::WriteLog('Checking call authorization for extension: ' . $callerid);
					/* is the extension authorized to make this call? */
					if ( $honcho->CallIsAuthorized($callerid, $mapping['map_id']) )
					{
						Logger::WriteLog('Authorized mapping: ' . $mapping['name']);
						/* this can be much, much better passing control to "Application Drivers"
						 * instead of having hard coded Applications
						 * */
						switch ( $mapping['name'] )
						{
							case RouteHoncho::APPLICATION_DIAL:
								$connector->Dial($channel, $mapping['data'] . '/' . $dialed_number);
								break;

							case RouteHoncho::APPLICATION_VOICEMAIL:
								$connector->EnterVoiceMail($channel, $dialed_number);
								break;
								
							case RouteHoncho::APPLICATION_CONFERENCE:
								$connector->StartConference($channel, $dialed_number);
								break;

							default:
								$connector->Playback($channel, 'iss_hangup_en');
								break;
						}
					}
					else
					{
						Logger::WriteLog('Unauthorized mapping: ' . $mapping['name']);
						$connector->Playback($channel, 'iss_invalid_pbx_number');
					}
				}	
			}
		}
		Logger::WriteLog('Sending packets');
		$connector->CommitCommands();
	}
}
catch ( Exception $error )
{
	print $error->getMessage() . "\n";
}
?>
