<?php
/**
 * @package stdlog
 */

/**
 * simple Logger class
 */
class Logger
{
	/**
	 * any log that has an log level higher or equal to LOG_LEVEL_DEBUG will be treated as debug info
	 */
	const LOG_LEVEL_DEBUG           = 10;
	
	/**
	 * any log that has an log level higher or equal to LOG_LEVEL_MESSAGE will be treated as a common message
	 */
	const LOG_LEVEL_MESSAGE         = 5;
	
	/**
	 * any log that has a log level higher or equal to LOG_LEVEL_WARNING will be treated as a warning message
	 */
	const LOG_LEVEL_WARNING         = 2;
	
	/**
	 * any log with this level will be sowed, and usually (always?), will stop the script
	 */
	const LOG_LEVEL_FATAL           = 0;
	
	/**
	 * verbosity level for the log messages
	 * @var int
	 */
	private static $log_level       = Logger::LOG_LEVEL_MESSAGE;
	
	/**
	 * alternative file to log
	 * @var string
	 */
	private static $log_file        = '';
	
	/**
	 * log file descriptor
	 * @var resource
	 */
	private static $log_descriptor  = STDOUT;
	
	/**
	 * simple log function
	 * @return void
	 * @param string $LogMessage
	 * @param int $LogLevel
	 */
	public static function WriteLog($LogMessage, $LogLevel = Logger::LOG_LEVEL_MESSAGE)
	{
		static $log_counter = 1;
		if ( Logger::$log_level >= $LogLevel )
		{
			switch ( $LogLevel )
			{
				case Logger::LOG_LEVEL_FATAL:
					$level = "FATAL";
					break;
				case Logger::LOG_LEVEL_WARNING:
					$level = "WARNING";
					break;
				case Logger::LOG_LEVEL_MESSAGE:
					$level = "MESSAGE";
					break;
				case Logger::LOG_LEVEL_DEBUG:
					$level = "DEBUG";
					break;
				default:
					$level = "UNKNOWN";
					break;
			}
			$caller     = isset($this) ? '['. get_class($this) . ']' : '';
			$log_output = "->{$log_counter} [{$level}]{$caller} {$LogMessage}\n";
			fwrite(Logger::$log_descriptor, $log_output);
			$log_counter++;
		}
	}
	
	public static function DumpLog($LogData, $LogLevel = Logger::LOG_LEVEL_MESSAGE)
	{
		ob_start();
		var_dump($LogData);
		$log_message = ob_get_contents();
		ob_end_clean();
		Logger::WriteLog("Logger Dump: {$log_message}", $LogLevel);
	}
	
	/**
	 * set file to log the messages. default file is php://stdout
	 * @return void
	 * @param int $LogLevel
	 */
	public static function SetLogFile($LogFile)
	{
		if ( ( $fd = fopen($LogFile, 'a') ) !== FALSE )
		{
			Logger::$log_file       = $LogFile;
			Logger::$log_descriptor = $fd;
		}
		else
		{
			Logger::WriteLog("Unable to open log file '{$LogFile}'", Logger::LOG_LEVEL_WARNING);
		}
	}

	/**
	 * set the log level ( a.k.a verbosity level ) in wich the server/client will be running
	 * @return void
	 * @param int $LogLevel
	 */
	public static function SetLogLevel($LogLevel)
	{
		Logger::$log_level = (int)$LogLevel;
	}
}
?>
